@@ -1,8 +1,8 @@
 import sys
 
-from utils.help import printHelp
-from utils.input import readConfigFile, parseInput
-from utils.version import printVersion
+from SSG.utils.help import printHelp
+from SSG.utils.input import readConfigFile, parseInput
+from SSG.utils.version import printVersion
 
 
 # Check if there's a parameter being passed for current option
@@ -69,5 +69,6 @@ def ssg():
         print(indexErr)
 
 
-if __name__ == "__main__":
+if __name__ == "__main__" or "main":
     ssg()
+    SystemExit()
